import pico.server
from django.http import HttpResponse
from django.views.decorators.csrf import csrf_exempt


@csrf_exempt
def index(request):
    params = {}
    params.update(request.GET.dict())
    params.update(request.POST.dict())
    path = '/' + request.path.split('/pico/')[-1]
    pico_response = pico.server.handle_api_v2(path, params)
    response = HttpResponse(pico_response.output)
    for key, header in pico_response.headers:
        response[key] = header
    return response


def picojs(request):
    f = open(pico.server.pico_path + 'client.js')
    return HttpResponse(f.read(), mimetype='application/javascript')



import os
from setuptools import setup

import djpico

README = open(os.path.join(os.path.dirname(__file__), 'README.md')).read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

version = djpico.__version__

setup(
    name='django-pico',
    version='0.0.1',
    packages=['djpico'],
    install_requires=['pico >= 1.2.1', 'django'],
    include_package_data=True,
    license='BSD License',
    description='A Django wrapper for the Pico web app framework',
    long_description=README,
    url='http://github.com/fergalwalsh/django-pico',
    download_url='https://github.com/fergalwalsh/django-pico/tarball/%s' % version,
    author='Fergal Walsh',
    author_email='fergalwalsh@gmail.com',
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)



from django.conf.urls import patterns, url

urlpatterns = patterns(
    '',
    url(r'pico.js|client.js', 'djpico.views.picojs', name='picojs'),
    url(r'^.*$', 'djpico.views.index', name='index'),
)
